==> alpaca-java-5.0.1-sources.jar: io/github/mainstringargs/alpaca/AlpacaConstants.java <==
package io.github.mainstringargs.alpaca;

/**
 * The Class AlpacaConstants.
 */
public class AlpacaConstants {

    /** The Constant VERSION_1. */
    public static final String VERSION_1_ENDPOINT = "v1";

    /** The Constant VERSION_2. */
    public static final String VERSION_2_ENDPOINT = "v2";

    /** The Constant SYMBOLS_PARAMETER. */
    public static final String SYMBOLS_PARAMETER = "symbols";

    /** The Constant END_PARAMETER. */
    public static final String END_PARAMETER = "end";

    /** The Constant START_PARAMETER. */
    public static final String START_PARAMETER = "start";

    /** The constant DATE_PARAMETER. */
    public static final String DATE_PARAMETER = "date";

    /** The Constant ASSET_CLASS_PARAMETER. */
    public static final String ASSET_CLASS_PARAMETER = "asset_class";

    /** The Constant CLIENT_ORDER_ID_PARAMETER. */
    public static final String CLIENT_ORDER_ID_PARAMETER = "client_order_id";

    /** The Constant STOP_PRICE_PARAMETER. */
    public static final String STOP_PRICE_PARAMETER = "stop_price";

    /** The Constant LIMIT_PRICE_PARAMETER. */
    public static final String LIMIT_PRICE_PARAMETER = "limit_price";

    /** The Constant TIME_IN_FORCE_PARAMETER. */
    public static final String TIME_IN_FORCE_PARAMETER = "time_in_force";

    /** The constant EXTENDED_HOURS_PARAMETER. */
    public static final String EXTENDED_HOURS_PARAMETER = "extended_hours";

    /** The Constant TYPE_PARAMETER. */
    public static final String TYPE_PARAMETER = "type";

    /** The Constant SIDE_PARAMETER. */
    public static final String SIDE_PARAMETER = "side";

    /** The Constant QTY_PARAMETER. */
    public static final String QTY_PARAMETER = "qty";

    /** The Constant SYMBOL_PARAMETER. */
    public static final String SYMBOL_PARAMETER = "symbol";

    /** The Constant DIRECTION_PARAMETER. */
    public static final String DIRECTION_PARAMETER = "direction";

    /** The Constant UNTIL_PARAMETER. */
    public static final String UNTIL_PARAMETER = "until";

    /** The Constant AFTER_PARAMETER. */
    public static final String AFTER_PARAMETER = "after";

    /** The Constant LIMIT_PARAMETER. */
    public static final String LIMIT_PARAMETER = "limit";

    /** The Constant STATUS_PARAMETER. */
    public static final String STATUS_PARAMETER = "status";

    /** The Constant BARS_ENDPOINT. */
    public static final String BARS_ENDPOINT = "bars";

    /** The Constant CLOCK_ENDPOINT. */
    public static final String CLOCK_ENDPOINT = "clock";

    /** The Constant CALENDAR_ENDPOINT. */
    public static final String CALENDAR_ENDPOINT = "calendar";

    /** The Constant ASSETS_ENDPOINT. */
    public static final String ASSETS_ENDPOINT = "assets";

    /** The Constant POSITIONS_ENDPOINT. */
    public static final String POSITIONS_ENDPOINT = "positions";

    /** The Constant ACCOUNT_ENDPOINT. */
    public static final String ACCOUNT_ENDPOINT = "account";

    /** The Constant ACTIVITIES_ENDPOINT. */
    public static final String ACTIVITIES_ENDPOINT = "activities";

    /** The Constant CONFIGURATIONS_ENDPOINT. */
    public static final String CONFIGURATIONS_ENDPOINT = "configurations";

    /** The Constant ORDERS_BY_CLIENT_ORDER_ID_ENDPOINT. */
    public static final String ORDERS_BY_CLIENT_ORDER_ID_ENDPOINT = "orders:by_client_order_id";

    /** The constant PAGE_SIZE_PARAMTER. */
    public static final String PAGE_SIZE_PARAMTER = "page_size";

    /** The constant PAGE_TOKEN_PARAMTER. */
    public static final String PAGE_TOKEN_PARAMTER = "page_token";

    /** The Constant ORDERS_ENDPOINT. */
    public static final String ORDERS_ENDPOINT = "orders";

    /** The Constant WATCHLISTS_ENDPOINT. */
    public static final String WATCHLISTS_ENDPOINT = "watchlists";

    /** The Constant UTF_ENCODING. */
    public static final String UTF_ENCODING = "UTF-8";

}

==> alpaca-java-5.0.12-sources.jar: io/github/mainstringargs/alpaca/AlpacaConstants.java <==
package io.github.mainstringargs.alpaca;

/**
 * The Class AlpacaConstants.
 */
public class AlpacaConstants {

    /** The Constant VERSION_1. */
    public static final String VERSION_1_ENDPOINT = "v1";

    /** The Constant VERSION_2. */
    public static final String VERSION_2_ENDPOINT = "v2";

    /** The Constant SYMBOLS_PARAMETER. */
    public static final String SYMBOLS_PARAMETER = "symbols";

    /** The Constant END_PARAMETER. */
    public static final String END_PARAMETER = "end";

    /** The Constant START_PARAMETER. */
    public static final String START_PARAMETER = "start";

    /** The constant DATE_PARAMETER. */
    public static final String DATE_PARAMETER = "date";

    /** The Constant ASSET_CLASS_PARAMETER. */
    public static final String ASSET_CLASS_PARAMETER = "asset_class";

    /** The Constant CLIENT_ORDER_ID_PARAMETER. */
    public static final String CLIENT_ORDER_ID_PARAMETER = "client_order_id";

    /** The constant ORDER_CLASS_PARAMETER. */
    public static final String ORDER_CLASS_PARAMETER = "order_class";

    /** The constant TAKE_PROFIT_PARAMETER. */
    public static final String TAKE_PROFIT_PARAMETER = "take_profit";

    /** The constant STOP_LOSS_PARAMETER. */
    public static final String STOP_LOSS_PARAMETER = "stop_loss";

    /** The Constant STOP_PRICE_PARAMETER. */
    public static final String STOP_PRICE_PARAMETER = "stop_price";

    /** The Constant LIMIT_PRICE_PARAMETER. */
    public static final String LIMIT_PRICE_PARAMETER = "limit_price";

    /** The Constant TIME_IN_FORCE_PARAMETER. */
    public static final String TIME_IN_FORCE_PARAMETER = "time_in_force";

    /** The constant EXTENDED_HOURS_PARAMETER. */
    public static final String EXTENDED_HOURS_PARAMETER = "extended_hours";

    /** The Constant TYPE_PARAMETER. */
    public static final String TYPE_PARAMETER = "type";

    /** The Constant SIDE_PARAMETER. */
    public static final String SIDE_PARAMETER = "side";

    /** The Constant QTY_PARAMETER. */
    public static final String QTY_PARAMETER = "qty";

    /** The Constant SYMBOL_PARAMETER. */
    public static final String SYMBOL_PARAMETER = "symbol";

    /** The Constant DIRECTION_PARAMETER. */
    public static final String DIRECTION_PARAMETER = "direction";

    /** The constant NESTED_PARAMETER. */
    public static final String NESTED_PARAMETER = "nested";

    /** The Constant UNTIL_PARAMETER. */
    public static final String UNTIL_PARAMETER = "until";

    /** The Constant AFTER_PARAMETER. */
    public static final String AFTER_PARAMETER = "after";

    /** The Constant LIMIT_PARAMETER. */
    public static final String LIMIT_PARAMETER = "limit";

    /** The Constant STATUS_PARAMETER. */
    public static final String STATUS_PARAMETER = "status";

    /** The constant PERIOD_PARAMETER. */
    public static final String PERIOD_PARAMETER = "period";

    /** The constant TIMEFRAME_PARAMETER. */
    public static final String TIMEFRAME_PARAMETER = "timeframe";

    /** The constant DATE_END_PARAMETER. */
    public static final String DATE_END_PARAMETER = "date_end";

    /** The Constant BARS_ENDPOINT. */
    public static final String BARS_ENDPOINT = "bars";

    /** The Constant CLOCK_ENDPOINT. */
    public static final String CLOCK_ENDPOINT = "clock";

    /** The Constant CALENDAR_ENDPOINT. */
    public static final String CALENDAR_ENDPOINT = "calendar";

    /** The Constant ASSETS_ENDPOINT. */
    public static final String ASSETS_ENDPOINT = "assets";

    /** The Constant POSITIONS_ENDPOINT. */
    public static final String POSITIONS_ENDPOINT = "positions";

    /** The Constant ACCOUNT_ENDPOINT. */
    public static final String ACCOUNT_ENDPOINT = "account";

    /** The Constant ACTIVITIES_ENDPOINT. */
    public static final String ACTIVITIES_ENDPOINT = "activities";

    /** The Constant CONFIGURATIONS_ENDPOINT. */
    public static final String CONFIGURATIONS_ENDPOINT = "configurations";

    /** The Constant ORDERS_BY_CLIENT_ORDER_ID_ENDPOINT. */
    public static final String ORDERS_BY_CLIENT_ORDER_ID_ENDPOINT = "orders:by_client_order_id";

    /** The constant PAGE_SIZE_PARAMETER. */
    public static final String PAGE_SIZE_PARAMETER = "page_size";

    /** The constant PAGE_TOKEN_PARAMETER. */
    public static final String PAGE_TOKEN_PARAMETER = "page_token";

    /** The Constant ORDERS_ENDPOINT. */
    public static final String ORDERS_ENDPOINT = "orders";

    /** The Constant WATCHLISTS_ENDPOINT. */
    public static final String WATCHLISTS_ENDPOINT = "watchlists";

    /** The constant PORTFOLIO_ENDPOINT. */
    public static final String PORTFOLIO_ENDPOINT = "portfolio";

    /** The constant HISTORY_ENDPOINT. */
    public static final String HISTORY_ENDPOINT = "history";

    /** The Constant UTF_ENCODING. */
    public static final String UTF_ENCODING = "UTF-8";

}
